import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ApplyflairService } from '../service/applyflair.service';
import {
  CDTO_applyflair,
  CVO_applyflair,
  FVO_applyflair,
  QDTO_applyflair,
  QVO_applyflair,
  UDTO_applyflair,
  UVAO_applyflair,
} from '../interface/applyflair.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['申请保留资质'])
@Controller('/applyflair')
export class ApplyflairController extends BaseController {
  @Inject()
  service: ApplyflairService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_applyflair })
  async create(@Body() data: CDTO_applyflair) {
    const dbData = await this.service.create(data);
    const result = new CVO_applyflair(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_applyflair })
  async query(
    @Query() filter: QDTO_applyflair,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_applyflair(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_applyflair })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_applyflair(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_applyflair })
  async update(@Param('id') id: string, @Body() body: UDTO_applyflair) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
