import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { BuilddesireService } from '../service/builddesire.service';
import {
  CDTO_builddesire,
  CVO_builddesire,
  FVO_builddesire,
  QDTO_builddesire,
  QVO_builddesire,
  UDTO_builddesire,
  UVAO_builddesire,
} from '../interface/builddesire.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['发布工作室建设意愿'])
@Controller('/builddesire')
export class BuilddesireController extends BaseController {
  @Inject()
  service: BuilddesireService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_builddesire })
  async create(@Body() data: CDTO_builddesire) {
    const dbData = await this.service.create(data);
    const result = new CVO_builddesire(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_builddesire })
  async query(
    @Query() filter: QDTO_builddesire,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_builddesire(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_builddesire })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_builddesire(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_builddesire })
  async update(@Param('id') id: string, @Body() body: UDTO_builddesire) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
