import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ContactofficeService } from '../service/contactoffice.service';
import {
  CDTO_contactoffice,
  CVO_contactoffice,
  FVO_contactoffice,
  QDTO_contactoffice,
  QVO_contactoffice,
  UDTO_contactoffice,
  UVAO_contactoffice,
} from '../interface/contactoffice.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['联系处室'])
@Controller('/contactoffice')
export class ContactofficeController extends BaseController {
  @Inject()
  service: ContactofficeService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_contactoffice })
  async create(@Body() data: CDTO_contactoffice) {
    const dbData = await this.service.create(data);
    const result = new CVO_contactoffice(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_contactoffice })
  async query(
    @Query() filter: QDTO_contactoffice,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_contactoffice(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_contactoffice })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_contactoffice(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_contactoffice })
  async update(@Param('id') id: string, @Body() body: UDTO_contactoffice) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
