import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { NoticeService } from '../service/notice.service';
import {
  CDTO_notice,
  CVO_notice,
  FVO_notice,
  QDTO_notice,
  QVO_notice,
  UDTO_notice,
  UVAO_notice,
} from '../interface/notice.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['通知公告'])
@Controller('/notice')
export class NoticeController extends BaseController {
  @Inject()
  service: NoticeService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_notice })
  async create(@Body() data: CDTO_notice) {
    const dbData = await this.service.create(data);
    const result = new CVO_notice(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_notice })
  async query(
    @Query() filter: QDTO_notice,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_notice(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_notice })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_notice(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_notice })
  async update(@Param('id') id: string, @Body() body: UDTO_notice) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
