import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { RelevantdownloadService } from '../service/relevantdownload.service';
import {
  CDTO_relevantdownload,
  CVO_relevantdownload,
  FVO_relevantdownload,
  QDTO_relevantdownload,
  QVO_relevantdownload,
  UDTO_relevantdownload,
  UVAO_relevantdownload,
} from '../interface/relevantdownload.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['相关下载'])
@Controller('/relevantdownload')
export class RelevantdownloadController extends BaseController {
  @Inject()
  service: RelevantdownloadService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_relevantdownload })
  async create(@Body() data: CDTO_relevantdownload) {
    const dbData = await this.service.create(data);
    const result = new CVO_relevantdownload(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_relevantdownload })
  async query(
    @Query() filter: QDTO_relevantdownload,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_relevantdownload(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_relevantdownload })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_relevantdownload(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_relevantdownload })
  async update(@Param('id') id: string, @Body() body: UDTO_relevantdownload) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
