import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { ScientistsettleService } from '../service/scientistsettle.service';
import {
  CDTO_scientistsettle,
  CVO_scientistsettle,
  FVO_scientistsettle,
  QDTO_scientistsettle,
  QVO_scientistsettle,
  UDTO_scientistsettle,
  UVAO_scientistsettle,
} from '../interface/scientistsettle.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['入驻科学家工作室'])
@Controller('/scientistsettle')
export class ScientistsettleController extends BaseController {
  @Inject()
  service: ScientistsettleService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_scientistsettle })
  async create(@Body() data: CDTO_scientistsettle) {
    const dbData = await this.service.create(data);
    const result = new CVO_scientistsettle(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_scientistsettle })
  async query(
    @Query() filter: QDTO_scientistsettle,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_scientistsettle(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_scientistsettle })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_scientistsettle(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_scientistsettle })
  async update(@Param('id') id: string, @Body() body: UDTO_scientistsettle) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
