import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TecholdemandService } from '../service/techoldemand.service';
import {
  CDTO_techoldemand,
  CVO_techoldemand,
  FVO_techoldemand,
  QDTO_techoldemand,
  QVO_techoldemand,
  UDTO_techoldemand,
  UVAO_techoldemand,
} from '../interface/techoldemand.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['技术需求'])
@Controller('/techoldemand')
export class TecholdemandController extends BaseController {
  @Inject()
  service: TecholdemandService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_techoldemand })
  async create(@Body() data: CDTO_techoldemand) {
    const dbData = await this.service.create(data);
    const result = new CVO_techoldemand(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_techoldemand })
  async query(
    @Query() filter: QDTO_techoldemand,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_techoldemand(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_techoldemand })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_techoldemand(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_techoldemand })
  async update(@Param('id') id: string, @Body() body: UDTO_techoldemand) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
