import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { TecholsupportService } from '../service/techolsupport.service';
import {
  CDTO_techolsupport,
  CVO_techolsupport,
  FVO_techolsupport,
  QDTO_techolsupport,
  QVO_techolsupport,
  UDTO_techolsupport,
  UVAO_techolsupport,
} from '../interface/techolsupport.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['技术支持'])
@Controller('/techolsupport')
export class TecholsupportController extends BaseController {
  @Inject()
  service: TecholsupportService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_techolsupport })
  async create(@Body() data: CDTO_techolsupport) {
    const dbData = await this.service.create(data);
    const result = new CVO_techolsupport(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_techolsupport })
  async query(
    @Query() filter: QDTO_techolsupport,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_techolsupport(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_techolsupport })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_techolsupport(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_techolsupport })
  async update(@Param('id') id: string, @Body() body: UDTO_techolsupport) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
