import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { YearreportService } from '../service/yearreport.service';
import {
  CDTO_yearreport,
  CVO_yearreport,
  FVO_yearreport,
  QDTO_yearreport,
  QVO_yearreport,
  UDTO_yearreport,
  UVAO_yearreport,
} from '../interface/yearreport.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['年度报告'])
@Controller('/yearreport')
export class YearreportController extends BaseController {
  @Inject()
  service: YearreportService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_yearreport })
  async create(@Body() data: CDTO_yearreport) {
    const dbData = await this.service.create(data);
    const result = new CVO_yearreport(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_yearreport })
  async query(
    @Query() filter: QDTO_yearreport,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_yearreport(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_yearreport })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_yearreport(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_yearreport })
  async update(@Param('id') id: string, @Body() body: UDTO_yearreport) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
